/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 * 
 * This file is part of de.bsvrz.pua.prot.
 * 
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.pua.prot.util;

import de.bsvrz.pua.prot.util.attributes.AttributeIdentifier;

import java.util.Objects;


/**
 * Qualifizierung von Referenzen. Diese Qualifizierung besteht aus allen Qualifizierungen, die ein Referenzattribut enthält.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class ReferenceQualifier extends Qualifier {

	/** Nächstes Glied der Referenzkette */
	private ReferenceQualifier _reference;

	/** Name des Referenzattributs */
	private final AttributeIdentifier _attributeIdent;

	/**
	 * @param qualifier Qualifizierung
	 * @param name      Attributname
	 */
	public ReferenceQualifier(final Qualifier qualifier, final AttributeIdentifier name) {
		super(qualifier.object, qualifier.attributeGroup, qualifier.aspect, qualifier.simVar);
		if(qualifier.freeAspect != null) this.freeAspect = qualifier.freeAspect;
		_attributeIdent = name;
		_reference = null;
	}

	/**
	 * Fügt eine weitere Qualifizierung hinzu
	 *
	 * @param qualifier Qualifizierung
	 * @param name      Attributname
	 *
	 * @return Hinzugefügte Qualifizierung
	 */
	public ReferenceQualifier addReference(final Qualifier qualifier, final AttributeIdentifier name) {
		_reference = new ReferenceQualifier(qualifier, name);
		return _reference;
	}

	/**
	 * Berechnet den Hashwert des Objekts
	 *
	 * @return Hashwert des Objekts
	 *
	 * @see java.lang.Object#hashCode()
	 */
	@Override
    public int hashCode() {
		int result = 0;

		if(_attributeIdent != null) result = _attributeIdent.hashCode();
		result = 37 * result + super.hashCode();
		if(_reference != null) result = 37 * result + _reference.hashCode();

		return result;
	}

	/** @see java.lang.Object#equals(java.lang.Object) */
	@Override
    public boolean equals(final Object obj) {
		if(obj instanceof ReferenceQualifier) {
			final ReferenceQualifier other = (ReferenceQualifier)obj;
			return super.equals(other) && Objects.equals(_attributeIdent, other.getAttributeIdent()) && Objects.equals(_reference, other.getReference());
		}
		else {
			return false;
		}
	}

	/** @see java.lang.Object#toString() */
	@Override
    public String toString() {
		final StringBuilder sb = new StringBuilder();
		sb.append(super.toString());
		if(_attributeIdent != null) sb.append(":").append(_attributeIdent);
		if(_reference != null) sb.append(" -> ").append(_reference.toString());
		return sb.toString();
	}

	public ReferenceQualifier getReference() {
		return _reference;
	}

	public AttributeIdentifier getAttributeIdent() {
		return _attributeIdent;
	}
}
